@@ -2,7 +2,6 @@ import h5py
 import sys
 import numpy as np
 import pandas as pd
-from Functions import GUI as G
 from Functions import Modelisation as mod
 import os
 import argparse
@@ -17,19 +16,14 @@ def parse():
     parser.add_argument('--inp', help='data location', dest='in_cfg' , default=None)
     parser.add_argument('--format', help='format of the plot', default='.jpg', dest='form')
     parser.add_argument('--dir', help='create input and output folder', action='store_true')
-    parser.add_argument('--hello',action='store_true',help='Launch thre web interface')
     return parser.parse_args()
 
 
 if __name__ == "__main__":
     args = parse()
-    if args.init:
-        G.interface()
-        print('Done')
-        sys.exit(0)
 
-    if args.hello:
-        os.system("streamlit run hello.py")
+    if args.init:
+        os.system("streamlit run /tmp/Interface.py")
     
     if args.out_cfg!=None and args.in_cfg!=None:
         mod.Data_read(args.in_cfg,args.out_cfg,args.form)
